@@ -4,8 +4,9 @@ import json
 from typing import Callable, AnyStr
 import warnings
 
-from arcane import datastore
 from arcane.core import CLIENTS_PARAM, ALL_CLIENTS_RIGHTS
+from arcane.datastore import Client as DatastoreClient
+from arcane.pubsub import Client as PubSubClient
 from flask import request
 from firebase_admin import auth as firebase_auth
 
@@ -25,6 +26,8 @@ class IncorrectAccessRightsRouteImplementation(TypeError):
 
 def check_access_rights(service: str,
                         required_rights: str,
+                        datastore_client: DatastoreClient,
+                        pubsub_client: PubSubClient,
                         receive_rights_per_client: bool=False,
                         auth_enabled: bool=True,
                         adscale_key: str=None,
@@ -78,7 +81,8 @@ def check_access_rights(service: str,
                         return {'detail': 'You don\'t have access to Adscale resources\n', 'firebase_log': str(e)}, 401
 
                 try:
-                    send_tracking_information(claims['email'], service, job_func.__name__, project, adscale_key)
+                    send_tracking_information(claims['email'], service, job_func.__name__, project, adscale_key,
+                                              pubsub_client, datastore_client)
                 except KeyError:
                     adscale_log(ServiceEnum.TRACKING, f'The user email is not contained in the claims')
 
@@ -97,8 +101,7 @@ def check_access_rights(service: str,
                                   f'Crushing existing value {str(kwargs[CLIENTS_PARAM])}')
                 if ALL_CLIENTS_RIGHTS in authorized_clients:
                     authorized_clients.remove(ALL_CLIENTS_RIGHTS)
-                    client = datastore.Client.from_service_account_json(adscale_key, project=project)
-                    clients_query = client.query()
+                    clients_query = datastore_client.query()
                     clients_query.kind = clients_kind
                     clients_query.keys_only()
                     authorized_clients.extend(
