@@ -8,17 +8,17 @@ from arcane.datastore import Client
 from arcane import pubsub
 from .log import adscale_log
 from .services import ServiceEnum
-
+from arcane.datastore import Client as DatastoreClient
+from arcane.pubsub import Client as PubSubClient
 
 PUBSUB_ACTIVITY_TRACKING_TOPIC = 'activity-tracker'
 
 
-def send_tracking_information(email: str, service: str, function_name: str, project: str, adscale_key: str) -> None:
+def send_tracking_information(email: str, service: str, function_name: str, project: str, adscale_key: str,
+                              pubsub_client: PubSubClient, datastore_client: DatastoreClient) -> None:
     """ Send pubsub message to the tracking cloud function"""
 
-    pubsub_client = pubsub.Client(adscale_key)
-
-    users_query = Client.query(kind='users')
+    users_query = datastore_client.query(kind='users')
     users_query.add_filter('email', '=', email)
     if users_query is None:
         adscale_log(ServiceEnum.TRACKING, f'User {email} is not an Adscale User. Tracking info will not be saved.')
@@ -26,7 +26,7 @@ def send_tracking_information(email: str, service: str, function_name: str, proj
         timestamp = datetime.now(tz=pytz.timezone('Europe/Paris')).strftime("%Y-%m-%dT%H:%M:%SZ")
         insert_id = str(uuid.uuid4())
 
-        pubsub_client(
+        pubsub_client.push_to_topic(
             project,
             PUBSUB_ACTIVITY_TRACKING_TOPIC,
             {'user_email': email,
